@@ -1,8 +1,9 @@
 package Import::Export;
 
 use Carp;
+use namespace::clean ();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 our %EX;
 
@@ -17,15 +18,22 @@ our %EXTYPE = (
 sub import {
 	my ($pkg) = shift;
 	return unless my @export = @_;
+	my $options = pop @export if ref $export[-1];
 
-	%EX = %{"${pkg}::EX"} or Carp::croak('define your %EX export hash');
-
+	Carp::croak('define your %EX export hash')
+		unless (%EX) = %{"${pkg}::EX"};
+	
 	my $caller = caller();
-	export($pkg, $caller, @export);
+	my @exported = export($pkg, $caller, @export);
+	
+	'namespace::clean'->import(
+			-cleanee => $caller,
+			@exported,
+	) if $options->{clean}; # stolen from https://metacpan.org/source/TOBYINK/PerlX-Define-0.101/lib/PerlX/Define.pm#L51 :)
 }
 
 sub export {
-	my ($pkg, $caller) = (shift, shift);
+	my ($pkg, $caller, @exported) = (shift, shift);
 	while (my $ex = shift) {
 		my $type;
 		if ( ! $EX{$ex} ) {
@@ -38,11 +46,13 @@ sub export {
 		}
 
 		$type = ($ex =~ s/^(\W)//) ? $1 : "&";
-		$pkg->can($type) and next;
+		$caller->can($ex) and next;
 
-		my $exporting = $EXTYPE{$type} or Carp::croak("Cant export symbol $ex");
+		my $exporting = $EXTYPE{$type} or Carp::croak("Cant export symbol $type");
 		*{"${caller}::${ex}"} = $exporting->($pkg, $ex);
+		push @exported, $ex;
 	}
+	return @expoted;
 }
 
 sub _export_code { \&{"$_[0]::$_[1]"} }
@@ -51,13 +61,17 @@ sub _export_array { \@{"$_[0]::$_[1]"} }
 sub _export_hash { \%{"$_[0]::$_[1]"} }
 sub _export_glob { *{"$_[0]::$_[1]"} }
 
+1;
+
+__END__
+
 =head1 NAME
 
 Import::Export - Exporting
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
@@ -82,7 +96,11 @@ Quick summary of what the module does.
 
 	.....
 
-	use One qw/one/;
+	use One qw/one/ { clean => 1 };
+
+=head2 import
+
+=head2 export
 
 =head1 AUTHOR
 
@@ -166,4 +184,3 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Import::Export
